use clap::{arg, command};

pub fn get_args() -> clap::ArgMatches {
    command!()
        .about("Git wrapper")
        .subcommand(
            command!("bootstrap")
                .about("Bootstrap a new repository from base repository")
                .arg(arg!(<BASE> "Base repository").required(true))
                .arg(arg!(<NEW> "Repository name").required(true))
                .alias("bs"),
        )
        .subcommand(
            command!("todo")
                .about("Show open TODOs in repository")
                .alias("t"),
        )
        .subcommand(
            command!("new")
                .about("Create a new branch")
                .arg(arg!(<BRANCH> "Branch name").required(true))
                .alias("n"),
        )
        .subcommand(
            command!("commit")
                .about("Commit current changes")
                .alias("c")
                .arg(arg!(-a --all "Add all changed files to commit"))
                .arg(arg!(-d --done "Only allow commiting if no TODOs are present"))
                .arg(
                    arg!(-i --interactive "Write interactive commit message with gitmoji standard")
                        .conflicts_with("message"),
                )
                .arg(arg!(-m --message <MSG> "Commit message").required(false)),
        )
        .subcommand(
            command!("remove")
                .about("Remove a branch")
                .arg(arg!(<BRANCH> "Branch name").required(true))
                .alias("r"),
        )
        .subcommand(command!("branch").about("Show branches").alias("b"))
        .subcommand(
            command!()
                .name("push")
                .about("Push to a remote")
                .arg(arg!(-f --force "Force push"))
                .alias("p"),
        )
        .subcommand(
            command!()
                .name("status")
                .about("Show git status")
                .alias("stat")
                .alias("stats"),
        )
        .subcommand(
            command!()
                .name("add")
                .about("Add files to git")
                .alias("a")
                .arg(arg!(<FILE>  "File to add").required(true)),
        )
        .subcommand(
            command!()
                .name("fetch")
                .about("Run git fetch --prune")
                .alias("f"),
        )
        .subcommand(
            command!()
                .name("pull")
                .about("Run git pull --prune")
                .alias("p"),
        )
        .subcommand(
            command!()
                .name("log")
                .about("Show git commit log")
                .alias("l"),
        )
        .subcommand(
            command!()
                .name("save")
                .about("Create a WIP commit")
                .alias("s"),
        )
        .get_matches()
}
